@@ -14,212 +14,170 @@ use Interchange6::Schema::Candy;
 
 =head2 orderlines_id
 
-  data_type: 'integer'
-  is_auto_increment: 1
-  is_nullable: 0
-  sequence: 'orderlines_orderlines_id_seq'
-  primary key
+Primary key.
 
 =cut
 
 primary_column orderlines_id => {
     data_type         => "integer",
     is_auto_increment => 1,
-    is_nullable       => 0,
     sequence          => "orderlines_orderlines_id_seq",
 };
 
 =head2 orders_id
 
-  data_type: 'integer'
-  is_foreign_key: 1
-  is_nullable: 0
+FK on L<Interchange6::Schema::Result::Order/orders_id>.
 
 =cut
 
 column orders_id =>
-  { data_type => "integer", is_foreign_key => 1, is_nullable => 0 };
+  { data_type => "integer", is_foreign_key => 1 };
 
 =head2 order_position
 
-  data_type: 'integer'
-  default_value: 0
-  is_nullable: 0
+Signed integer order position. Defaults to 0.
 
 =cut
 
 column order_position =>
-  { data_type => "integer", default_value => 0, is_nullable => 0 };
+  { data_type => "integer", default_value => 0 };
 
 =head2 sku
 
-  data_type: 'varchar'
-  is_foreign_key: 1
-  is_nullable: 0
-  size: 64
+FK on L<Interchange6::Schema::Result::Product/sku>.
 
 =cut
 
 column sku =>
-  { data_type => "varchar", is_foreign_key => 1, is_nullable => 0, size => 64 };
+  { data_type => "varchar", is_foreign_key => 1, size => 64 };
 
 =head2 name
 
-  data_type: 'varchar'
-  default_value: (empty string)
-  is_nullable: 0
-  size: 255
+Product name.
 
 =cut
 
 column name => {
     data_type     => "varchar",
-    default_value => "",
-    is_nullable   => 0,
     size          => 255
 };
 
 =head2 short_description
 
-  data_type: 'varchar'
-  default_value: (empty string)
-  is_nullable: 0
-  size: 500
+Product short description.
+
+Defaults to empty string.
 
 =cut
 
 column short_description => {
     data_type     => "varchar",
     default_value => "",
-    is_nullable   => 0,
     size          => 500
 };
 
 =head2 description
 
-  data_type: 'text'
-  is_nullable: 0
+Product descrtption.
 
 =cut
 
-column description => { data_type => "text", is_nullable => 0 };
+column description => { data_type => "text" };
 
 =head2 weight
 
-  data_type: 'numeric'
-  default_value: 0.0
-  is_nullable: 0
-  size: [10,3]
+Weight of product. Defaults to 0.
 
 =cut
 
 column weight => {
     data_type     => "numeric",
     default_value => "0.0",
-    is_nullable   => 0,
     size          => [ 10, 3 ]
 };
 
 =head2 quantity
 
-  data_type: 'integer'
-  is_nullable: 1
+Product quantity.
 
 =cut
 
-column quantity => { data_type => "integer", is_nullable => 1 };
+column quantity => { data_type => "integer" };
 
 =head2 price
 
-  data_type: 'numeric'
-  default_value: 0.0
-  is_nullable: 0
-  size: [10,2]
+Product price.
 
 =cut
 
 column price => {
     data_type     => "numeric",
-    default_value => "0.0",
-    is_nullable   => 0,
     size          => [ 10, 2 ],
 };
 
 =head2 subtotal
 
-  data_type: 'numeric'
-  default_value: 0.0
-  is_nullable: 0
-  size: [11,2]
+Line subtotal.
 
 =cut
 
 column subtotal => {
     data_type     => "numeric",
-    default_value => "0.0",
-    is_nullable   => 0,
     size          => [ 11, 2 ],
 };
 
 =head2 shipping
 
-  data_type: 'numeric'
-  default_value: 0.0
-  is_nullable: 0
-  size: [11,2]
+Shipping cost.
+
+Defaults to 0.
 
 =cut
 
 column shipping => {
     data_type     => "numeric",
     default_value => "0.0",
-    is_nullable   => 0,
     size          => [ 11, 2 ],
 };
 
 =head2 handling
 
-  data_type: 'numeric'
-  default_value: 0.0
-  is_nullable: 0
-  size: [11,2]
+Handling cost.
+
+Defaults to 0.
 
 =cut
 
 column handling => {
     data_type     => "numeric",
     default_value => "0.0",
-    is_nullable   => 0,
     size          => [ 11, 2 ],
 };
 
 =head2 salestax
 
-  data_type: 'numeric'
-  default_value: 0.0
-  is_nullable: 0
-  size: [11,2]
+Sales tax.
+
+Defaults to 0.
 
 =cut
 
 column salestax => {
     data_type     => "numeric",
     default_value => "0.0",
-    is_nullable   => 0,
     size          => [ 11, 2 ],
 };
 
 =head2 status
 
-  data_type: 'varchar'
-  default_value: (empty string)
-  is_nullable: 0
-  size: 24
+Status, e.g.: picking, shipped, cancelled.
+
+Defaults to empty string.
 
 =cut
 
 column status =>
-  { data_type => "varchar", default_value => "", is_nullable => 0, size => 24 };
+  { data_type => "varchar", default_value => "", size => 24 };
 
 =head1 RELATIONS
 
