@@ -13,21 +13,10 @@ use warnings;
 use DateTime;
 use POSIX qw/ceil floor/;
 
-use base 'DBIx::Class::Core';
-
-use namespace::clean;
-
-# component load order is important so be careful here:
-__PACKAGE__->load_components(
+use Interchange6::Schema::Candy -components => [
     qw(InflateColumn::DateTime TimeStamp
       +Interchange6::Schema::Component::Validation)
-);
-
-=head1 TABLE: C<taxes>
-
-=cut
-
-__PACKAGE__->table("taxes");
+];
 
 =head1 DESCRIPTION
 
@@ -37,126 +26,166 @@ The taxes table contains taxes such as sales tax and VAT. Each tax has a unique
 
 =head2 taxes_id
 
-  data_type: 'integer'
-  is_auto_increment: 1
-  is_nullable: 0
-  sequence: 'taxes_id_seq'
-
-=head2 tax_name
-
-  data_type: 'varchar'
-  is_nullable: 0
-  size: 64
-
-=head2 description
-
-  data_type: 'varchar'
-  is_nullable: 0
-  size: 64
-
-=head2 percent
-
-  data_type: 'numeric'
-  is_nullable: 0
-  size: [7,4]
-
-=head2 decimal_places
-
-  data_type: 'integer'
-  is_nullable: 0
-  default_value: 2
-
-Number of decimal_places of precision required. Defaults to 2.
-
-=head2 rounding
-
-  data_type: char"
-  is_nullable: 1
-  size: 1
-  default_value: undef
-
-Default rounding is half round up to the number of decimal_places. To use floor or ceiling set rounding to 'f' or 'c' as appropriate. The rounding value is automatically converted to lower case and any invalid value passed in will cause an exception to be thrown.
-
-=head2 valid_from
-
-  data_type: 'date'
-  set_on_create: 1
-  is_nullable: 0
-
-=head2 valid_to
-
-  data_type: 'date'
-  is_nullable: 1
-
-=head2 country_iso_code
-
-  data_type: 'char'
-  is_foreign_key: 1
-  is_nullable: 1
-  size: 2
-
-=head2 states_id
-
-  data_type: 'integer'
-  is_foreign_key: 1
-  is_nullable: 1
-
-=head2 created
-
-  data_type: 'datetime'
-  set_on_create: 1
-  is_nullable: 0
-
-=head2 last_modified
-
-  data_type: 'datetime'
-  set_on_create: 1
-  set_on_update: 1
-  is_nullable: 0
+Primary key.
 
 =cut
 
-__PACKAGE__->add_columns(
-    "taxes_id",
-    {
-        data_type         => "integer",
-        is_auto_increment => 1,
-        is_nullable       => 0,
-        sequence          => "taxes_id_seq"
-    },
-    "tax_name",
-    { data_type => "varchar", is_nullable => 0, size => 64 },
-    "description",
-    { data_type => "varchar", is_nullable => 0, size => 64 },
-    "percent",
-    { data_type => "numeric", is_nullable => 0, size => [ 7, 4 ] },
-    "decimal_places",
-    { data_type => "integer", is_nullable => 0, default_value => 2 },
-    "rounding",
-    {
-        data_type     => "char",
-        is_nullable   => 1,
-        size          => 1,
-        default_value => undef
-    },
-    "valid_from",
-    { data_type => "date", set_on_create => 1, is_nullable => 0 },
-    "valid_to",
-    { data_type => "date", is_nullable => 1 },
-    "country_iso_code",
-    { data_type => "char", is_foreign_key => 1, is_nullable => 1, size => 2 },
-    "states_id",
-    { data_type => "integer", is_foreign_key => 1, is_nullable => 1 },
-    "created",
-    { data_type => "datetime", set_on_create => 1, is_nullable => 0 },
-    "last_modified",
-    {
-        data_type     => "datetime",
-        set_on_create => 1,
-        set_on_update => 1,
-        is_nullable   => 0
-    },
-);
+primary_column taxes_id => {
+    data_type         => "integer",
+    is_auto_increment => 1,
+    sequence          => "taxes_id_seq"
+};
+
+=head2 tax_name
+
+Name of tax, e.g.: vat_full
+
+=cut
+
+column tax_name => { data_type => "varchar", size => 64 };
+
+=head2 description
+
+Description of tax, e.g.: New York sales tax
+
+=cut
+
+column description => { data_type => "varchar", size => 64 };
+
+=head2 percent
+
+Percent rate of tax, e.g.: 19.9775
+
+=cut
+
+column percent =>
+  { data_type => "numeric", size => [ 7, 4 ] };
+
+=head2 decimal_places
+
+Number of decimal_places of precision required for tax cost and reporting.
+
+Defaults to 2.
+
+=cut
+
+column decimal_places =>
+  { data_type => "integer", default_value => 2 };
+
+=head2 rounding
+
+Default rounding is half round up to the number of decimal_places. To use floor or ceiling set rounding to 'f' or 'c' as appropriate. The rounding value is automatically converted to lower case and any invalid value passed in will cause an exception to be thrown.
+
+Is nullable.
+
+=cut
+
+column rounding =>
+  { data_type => "char", is_nullable => 1, size => 1 };
+
+=head2 valid_from
+
+Date from which tax is valid. Defaults to time record is created.
+
+=cut
+
+column valid_from =>
+  { data_type => "date", set_on_create => 1 };
+
+=head2 valid_to
+
+Final date on which tax is valid.
+
+Is nullable.
+
+=cut
+
+column valid_to => { data_type => "date", is_nullable => 1 };
+
+=head2 country_iso_code
+
+FK on L<Interchange6::Schema::Result::Country/country_iso_code>.
+
+Is nullable.
+
+=cut
+
+column country_iso_code =>
+  { data_type => "char", is_foreign_key => 1, is_nullable => 1, size => 2 };
+
+=head2 states_id
+
+FK on L<Interchange6::Schema::Result::State/states_id>.
+
+Is nullable.
+
+=cut
+
+column states_id =>
+  { data_type => "integer", is_foreign_key => 1, is_nullable => 1 };
+
+=head2 created
+
+Date and time when this record was created returned as L<DateTime> object.
+Value is auto-set on insert.
+
+=cut
+
+column created =>
+  { data_type => "datetime", set_on_create => 1 };
+
+=head2 last_modified
+
+Date and time when this record was last modified returned as L<DateTime> object.
+Value is auto-set on insert and update.
+
+=cut
+
+column last_modified => {
+    data_type     => "datetime",
+    set_on_create => 1,
+    set_on_update => 1,
+};
+
+=head1 RELATIONS
+
+=head2 state
+
+Type: belongs_to
+
+Related object: L<Interchange6::Schema::Result::State>
+
+=cut
+
+belongs_to
+  state => "Interchange6::Schema::Result::State",
+  'states_id',
+  {
+    is_deferrable => 1,
+    on_delete     => "CASCADE",
+    on_update     => "CASCADE",
+    order_by      => 'name',
+    join_type     => 'left',
+  };
+
+=head2 country
+
+Type: belongs_to
+
+Related object: L<Interchange6::Schema::Result::Country>
+
+=cut
+
+belongs_to
+  country => "Interchange6::Schema::Result::Country",
+  'country_iso_code',
+  {
+    is_deferrable => 1,
+    on_delete     => "CASCADE",
+    on_update     => "CASCADE",
+    order_by      => 'name',
+    join_type     => 'left',
+  };
 
 =head1 METHODS
 
@@ -241,62 +270,6 @@ sub calculate {
     }
 }
 
-=head1 PRIMARY KEY
-
-=over 4
-
-=item * L</taxes_id>
-
-=back
-
-=cut
-
-__PACKAGE__->set_primary_key("taxes_id");
-
-=head1 RELATIONS
-
-=head2 state
-
-Type: belongs_to
-
-Related object: L<Interchange6::Schema::Result::State>
-
-=cut
-
-__PACKAGE__->belongs_to(
-    "state",
-    "Interchange6::Schema::Result::State",
-    'states_id',
-    {
-        is_deferrable => 1,
-        on_delete     => "CASCADE",
-        on_update     => "CASCADE",
-        order_by      => 'name',
-        join_type     => 'left',
-    }
-);
-
-=head2 country
-
-Type: belongs_to
-
-Related object: L<Interchange6::Schema::Result::Country>
-
-=cut
-
-__PACKAGE__->belongs_to(
-    "country",
-    "Interchange6::Schema::Result::Country",
-    'country_iso_code',
-    {
-        is_deferrable => 1,
-        on_delete     => "CASCADE",
-        on_update     => "CASCADE",
-        order_by      => 'name',
-        join_type     => 'left',
-    }
-);
-
 =head1 INHERITED METHODS
 
 =head2 new
@@ -347,8 +320,6 @@ sub sqlt_deploy_hook {
     );
 }
 
-=head1 INHERITED METHODS
-
 =head2 validate
 
 Validity checks that cannot be enforced using primary key, unique or other database methods using L<Interchange6::Schema::Component::Validation>. The validity checks enforce the following rules:
